use axum::Json;
use axum_extra::extract::WithRejection;
use domain::dto::account::AccountRegister;
use library::resp::{rejection::IRejection, response::{ResErr, ResOK, ResResult}};
use validator::Validate;

pub async fn create(
    WithRejection(Json(req), _): IRejection<Json<AccountRegister>>
) -> ResResult<ResOK<()>> {
    if let Err(err) = req.validate() {
        return Err(ResErr::ErrParams(Some(err.to_string())));
    }

    service::account::register(req).await?;

    Ok(ResOK(None))
}
